%global debug_package %{nil}

Summary:       Fast JSON parser and generator for C++
Name:          rapidjson
Version:       1.1.0
Release:       5%{?dist}
License:       MIT
URL:           http://rapidjson.org/
Source0:       https://github.com/Tencent/rapidjson/archive/v%{version}/%{name}-%{version}.tar.gz

Patch3000:     rapidjson-1.1.0-do_not_include_gtest_src_dir.patch
Patch3001:     rapidjson-1.1.0-c++20.patch

BuildRequires: cmake make gcc-c++ gtest-devel valgrind doxygen

%description
RapidJSON is a fast JSON parser and generator for C++.  It was        
inspired by RapidXml.                            
 
  RapidJSON is small but complete.  It supports both SAX and DOM style    
  API. The SAX parser is only a half thousand lines of code.        
 
  RapidJSON is fast.  Its performance can be comparable to strlen().    
  It also optionally supports SSE2/SSE4.1 for acceleration.        
 
  RapidJSON is self-contained.  It does not depend on external        
  libraries such as BOOST.  It even does not depend on STL.        
 
  RapidJSON is memory friendly.  Each JSON value occupies exactly    
  16/20 bytes for most 32/64-bit machines (excluding text string).  By    
  default it uses a fast memory allocator, and the parser allocates    
  memory compactly during parsing.                    
 
  RapidJSON is Unicode friendly.  It supports UTF-8, UTF-16, UTF-32    
  (LE & BE), and their detection, validation and transcoding        
  internally.  For example, you can read a UTF-8 file and let RapidJSON    
  transcode the JSON strings into UTF-16 in the DOM.  It also supports    
  surrogates and "\u0000" (null character).                
 
JSON(JavaScript Object Notation) is a light-weight data exchange    
format.  RapidJSON should be in fully compliance with RFC4627/ECMA-404.


%package devel
Summary:        %{summary}
Provides:    %{name} = %{version}-%{release}
Provides:    %{name}-static = %{version}-%{release}
Provides:    %{name}-doc = %{version}-%{release}
Obsoletes:    %{name}-doc <= %{version}-%{release}

%description devel
%{description}
This package also contains the documentation-files for %{name}.

%prep
%autosetup -p 1 -n %{name}-%{version}

rm -rf thirdparty
find . -type f -name CMakeLists.txt -print0 | xargs -0r sed -i -e "s/-march=native/ /g" -e "s/-Werror//g"

%build
%cmake \
    -DDOC_INSTALL_DIR:PATH=%{_pkgdocdir} \
    -DRAPIDJSON_BUILD_CXX11:BOOL=OFF \
    -DGTESTSRC_FOUND:BOOL=ON \
    -DGTEST_SOURCE_DIR:PATH=.
%cmake_build

%install
%cmake_install
install -pm 644 CHANGELOG.md readme*.md %{buildroot}%{_pkgdocdir}/
find %{buildroot} -type f -name 'CMake*.txt' -delete

%check
%ctest

%files devel
%license license.txt
%dir %{_pkgdocdir}
%{_pkgdocdir}/CHANGELOG.md
%{_pkgdocdir}/readme*.md
%{_libdir}/cmake/RapidJSON/
%{_libdir}/pkgconfig/*.pc
%{_includedir}/%{name}/
%{_pkgdocdir}/

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.0-5
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Aug 14 2023 Shuo Wang <abushwang@tencent.com> - 1.1.0-4
- update cmake config to do not force C++11 because that
- gtest 1.13.0 requires at least C++14

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.0-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Nov 29 2022 Shuo Wang <abushwang@tencent.com> - 1.1.0-1
- initial build
